@@ -15,7 +15,7 @@
 */
 
 /* Includes. */
-#include "sampling.h"
+#include "bas.h"
 
 void   update_MCMC_freq(double *MCMC_probs, int *model, int p, int m);
 double cond_prob(double *model, int j, int n, double *mean, double *beta_matrix , double eps);
@@ -25,16 +25,16 @@ void update_cond_tree(SEXP modelspace, struct Node *tree, SEXP modeldim, struct
 void  update_Cov(double *Cov, double *priorCov, double *SSgam, double *marg_probs, int n, int m, int print);
 
 void insert_model_tree(struct Node *tree, struct Var *vars,  int n, int *model, int num_models);
- 
+
 SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP incint, SEXP Ralpha,SEXP method, SEXP modelprior, SEXP Rupdate, SEXP Rbestmodel, SEXP plocal, SEXP BURNIN_Iterations, SEXP MCMC_Iterations, SEXP LAMBDA, SEXP DELTA)
 {
-  SEXP   Rse_m, Rcoef_m, Rmodel_m; 
+  SEXP   Rse_m, Rcoef_m, Rmodel_m;
 
   SEXP   RXwork = PROTECT(duplicate(X)), RYwork = PROTECT(duplicate(Y));
 
   int nProtected = 2, nUnique=0, newmodel=0;
   int nModels=LENGTH(Rmodeldim);
-  
+
   //  Rprintf("Allocating Space for %d Models\n", nModels) ;
   SEXP ANS = PROTECT(allocVector(VECSXP, 15)); ++nProtected;
   SEXP ANS_names = PROTECT(allocVector(STRSXP, 15)); ++nProtected;
@@ -61,10 +61,10 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
   int mcurrent,  update, n_sure;
   double  mod, rem, problocal, *pigamma, pigammaold, pigammanew, eps, *hyper_parameters;
   double *XtX, *XtY, *XtXwork, *XtYwork, *SSgam, *Cov, *priorCov, *marg_probs;
-  double one=1.0, lambda,  delta, wt = 1.0; 
- 
+  double one=1.0, lambda,  delta, wt = 1.0;
+
   int inc=1, print = 0;
-  int *model, *modelold, bit, *modelwork, old_loc, new_loc;	
+  int *model, *modelold, bit, *modelwork, old_loc, new_loc;
   struct Var *vars;	/* Info about the model variables. */
   NODEPTR tree, branch;
 
@@ -90,14 +90,14 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
   Ywork = REAL(RYwork);
   Xwork = REAL(RXwork);
   wts = REAL(Rweights);
- 
+
   PrecomputeData(Xwork, Ywork, wts, &XtXwork, &XtYwork, &XtX, &XtY, &yty, &SSY, p, nobs);
 
   alpha = REAL(Ralpha)[0];
 
   vars = (struct Var *) R_alloc(p, sizeof(struct Var));
   probs =  REAL(Rprobs);
-  n = sortvars(vars, probs, p); 
+  n = sortvars(vars, probs, p);
 
   for (i =0; i <n; i++) REAL(MCMCprobs)[vars[i].index] = 0.0;
   MCMC_probs =  REAL(MCMCprobs);
@@ -128,17 +128,17 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
   }
 
 
-  /* Make space for the models and working variables. */ 
+  /* Make space for the models and working variables. */
 
-  /*  pivot = ivecalloc(p); 
+  /*  pivot = ivecalloc(p);
   qraux = vecalloc(p);
   work =  vecalloc(2 * p);
-  effects = vecalloc(nobs); 
-  v =  vecalloc(p * p); 
+  effects = vecalloc(nobs);
+  v =  vecalloc(p * p);
   betaols = vecalloc(p);
   */
 
- 
+
 
   /*  Rprintf("Fit Full Model\n"); */
 
@@ -146,14 +146,14 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
   else {
     PROTECT(Rcoef_m = NEW_NUMERIC(p));
     PROTECT(Rse_m = NEW_NUMERIC(p));
-    coefficients = REAL(Rcoef_m);  
+    coefficients = REAL(Rcoef_m);
     se_m = REAL(Rse_m);
     memcpy(coefficients, XtY,  p*sizeof(double));
     memcpy(XtXwork, XtX, p*p*sizeof(double));
     memcpy(XtYwork, XtY,  p*sizeof(double));
 
-    mse_m = yty; 
-    cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, p, nobs);  
+    mse_m = yty;
+    cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, p, nobs);
 
   /*olsreg(Ywork, Xwork,  coefficients, se_m, &mse_m, &p, &nobs, pivot,qraux,work,residuals,effects,v, betaols); */
     RSquareFull =  1.0 - (mse_m * (double) ( nobs - p))/SSY;
@@ -184,7 +184,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
    for (i = 0; i< n; i++) {
       bit =  bestmodel[vars[i].index];
       if (bit == 1) {
-	if (i < n-1 && branch->one == NULL) 
+	if (i < n-1 && branch->one == NULL)
 	  branch->one = make_node(-1.0);
 	if (i == n-1 && branch->one == NULL)
 	  branch->one = make_node(0.0);
@@ -196,22 +196,22 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 	if (i == n-1 && branch->zero == NULL)
 	  branch->zero = make_node(0.0);
 	branch = branch->zero;
-      } 
-      
-      model[vars[i].index] = bit; 
+      }
+
+      model[vars[i].index] = bit;
       INTEGER(modeldim)[m]  += bit;
       branch->where = 0;
    }
-  
+
 
 
     /*    Rprintf("Now get model specific calculations \n"); */
- 
+
     pmodel = INTEGER(modeldim)[m];
     PROTECT(Rmodel_m = allocVector(INTSXP,pmodel));
     model_m = INTEGER(Rmodel_m);
 
-      for (j = 0, l=0; j < p; j++) {  
+      for (j = 0, l=0; j < p; j++) {
 	if (model[j] == 1) {
             model_m[l] = j;
            l +=1;}
@@ -221,7 +221,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 
     Rcoef_m = NEW_NUMERIC(pmodel); PROTECT(Rcoef_m);
     Rse_m = NEW_NUMERIC(pmodel);   PROTECT(Rse_m);
-    coefficients = REAL(Rcoef_m);  
+    coefficients = REAL(Rcoef_m);
     se_m = REAL(Rse_m);
 
       for (j=0, l=0; j < pmodel; j++) {
@@ -229,12 +229,12 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
         for  ( i = 0; i < pmodel; i++) {
 	  XtXwork[j*pmodel + i] = XtX[model_m[j]*p + model_m[i]];
 	}
-      } 
+      }
 
-      
-    mse_m = yty; 
-    memcpy(coefficients, XtYwork, sizeof(double)*pmodel); 
-    cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);  
+
+    mse_m = yty;
+    memcpy(coefficients, XtYwork, sizeof(double)*pmodel);
+    cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);
 
     R2_m = 1.0 - (mse_m * (double) ( nobs - pmodel))/SSY;
 
@@ -263,11 +263,11 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
   /*   Rprintf("model %d max logmarg %lf\n", m, REAL(logmarg)[m]); */
 
     /*  Rprintf("Now Sample the Rest of the Models \n");  */
-    
-  
+
+
   m = 0;
 
-  //  Need to fix in case the number of sampled models exceeds the space! 
+  //  Need to fix in case the number of sampled models exceeds the space!
   while (m < INTEGER(BURNIN_Iterations)[0]) {
 
     memcpy(model, modelold, sizeof(int)*p);
@@ -288,13 +288,13 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 	MH =  random_walk(model, vars,  n);
       }
     }
-    
+
     branch = tree;
     newmodel= 0;
 
     for (i = 0; i< n; i++) {
       bit =  model[vars[i].index];
-      
+
       if (bit == 1) {
 	if (branch->one != NULL) branch = branch->one;
 	else newmodel = 1;
@@ -302,7 +302,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
       else {
 	if (branch->zero != NULL)  branch = branch->zero;
 	else newmodel = 1.0;
-      } 
+      }
       pmodel  += bit;
     }
 
@@ -312,26 +312,26 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
       new_loc = nUnique;
       PROTECT(Rmodel_m = allocVector(INTSXP,pmodel));
       model_m = INTEGER(Rmodel_m);
-      for (j = 0, l=0; j < p; j++) {  
+      for (j = 0, l=0; j < p; j++) {
 	if (model[j] == 1) {
 	  model_m[l] = j;
 	  l +=1;}
-      }	
+      }
 
       Rcoef_m = NEW_NUMERIC(pmodel); PROTECT(Rcoef_m);
       Rse_m = NEW_NUMERIC(pmodel);   PROTECT(Rse_m);
-      coefficients = REAL(Rcoef_m);  
+      coefficients = REAL(Rcoef_m);
       se_m = REAL(Rse_m);
       for (j=0, l=0; j < pmodel; j++) {
         XtYwork[j] = XtY[model_m[j]];
         for  ( i = 0; i < pmodel; i++) {
 	  XtXwork[j*pmodel + i] = XtX[model_m[j]*p + model_m[i]];
-	}	
-      }	 
+	}
+      }
 
-      mse_m = yty; 
-      memcpy(coefficients, XtYwork, sizeof(double)*pmodel); 
-      cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);  
+      mse_m = yty;
+      memcpy(coefficients, XtYwork, sizeof(double)*pmodel);
+      cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);
 
       R2_m = 1.0 - (mse_m * (double) ( nobs - pmodel))/SSY;
       prior_m = compute_prior_probs(model,pmodel,p, modelprior);
@@ -340,8 +340,8 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
     }
     else {
       new_loc = branch->where;
-      postnew =  REAL(logmarg)[new_loc] + log(REAL(priorprobs)[new_loc]);      
-    } 
+      postnew =  REAL(logmarg)[new_loc] + log(REAL(priorprobs)[new_loc]);
+    }
 
     MH *= exp(postnew - postold);
     //    Rprintf("MH new %lf old %lf\n", postnew, postold);
@@ -364,7 +364,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 	REAL(shrinkage)[nUnique] = shrinkage_m;
 	REAL(priorprobs)[nUnique] = prior_m;
 	UNPROTECT(3);
-	++nUnique; 
+	++nUnique;
       }
 
       old_loc = new_loc;
@@ -377,36 +377,36 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
     }
 
     INTEGER(counts)[old_loc] += 1;
-    
+
     for (i = 0; i < n; i++) {
      real_model[i] = (double) modelold[vars[i].index];
      REAL(MCMCprobs)[vars[i].index] += (double) modelold[vars[i].index];
    }
 
-   // Update SSgam = gamma gamma^T + SSgam 
+   // Update SSgam = gamma gamma^T + SSgam
    F77_NAME(dsyr)("U", &n,  &one, &real_model[0], &inc,  &SSgam[0], &n);
    m++;
   }
-  
+
   //  Rprintf("\n%d Unique models sampled during burnin\n", nUnique);
 
 
-// Compute marginal probabilities  
+// Compute marginal probabilities
   mcurrent = nUnique;
   compute_modelprobs(modelprobs, logmarg, priorprobs,mcurrent);
-  compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);        
+  compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);
   for (i = 0; i < n; i++) {
-    marg_probs[i] = wt*(REAL(MCMCprobs)[vars[i].index]/ (double) m) + 
+    marg_probs[i] = wt*(REAL(MCMCprobs)[vars[i].index]/ (double) m) +
       (1.0 - wt)* probs[vars[i].index];
-  }	
+  }
   //  print=1;
   update_Cov(Cov, priorCov, SSgam, marg_probs, n, m, print);
- 
+
 // Global-Proposal
 // Initialize post old proposal
  pigammaold = 0.0;
  for (i = 0; i < n; i++) {
-   if (modelold[vars[i].index] == 1 ){	
+   if (modelold[vars[i].index] == 1 ){
      real_model[i] = 1.0;
      pigammaold += log(cond_prob(real_model,i, n, marg_probs,Cov, delta));
    }
@@ -415,10 +415,10 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
      pigammaold += log(1.0 - cond_prob(real_model,i, n, marg_probs,Cov, delta));
    }
  }
- 
-//  need to fix to make sure that nUnique is less than nModels 
 
- while (m < INTEGER(BURNIN_Iterations)[0] + INTEGER(MCMC_Iterations)[0]) {  
+//  need to fix to make sure that nUnique is less than nModels
+
+ while (m < INTEGER(BURNIN_Iterations)[0] + INTEGER(MCMC_Iterations)[0]) {
       // for (m = 0; m < k; m++) {
    memcpy(model, modelold, sizeof(int)*p);
    pmodel =  n_sure;
@@ -429,7 +429,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
    for (i = 0; i < n; i++) {
      prob_i = cond_prob(real_model,i, n, marg_probs,Cov,delta);
      bit =  withprob(prob_i);
-     
+
      if (bit == 1) {
        pigammanew += log(prob_i);
        if (branch->one != NULL) branch = branch->one;
@@ -439,8 +439,8 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
        pigammanew += log(1.0 - prob_i);
        if (branch->zero != NULL) branch = branch->zero;
        else newmodel= 1;
-     } 
-     model[vars[i].index] = bit; 
+     }
+     model[vars[i].index] = bit;
      real_model[i] = (double) bit;
      pmodel  += bit;
    }
@@ -448,41 +448,41 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
      new_loc = nUnique;
      PROTECT(Rmodel_m = allocVector(INTSXP,pmodel));
      model_m = INTEGER(Rmodel_m);
-     for (j = 0, l=0; j < p; j++) {  
+     for (j = 0, l=0; j < p; j++) {
        if (model[j] == 1) {
 	 model_m[l] = j;
 	 l +=1;}
-     }	
+     }
 
      Rcoef_m = NEW_NUMERIC(pmodel); PROTECT(Rcoef_m);
      Rse_m = NEW_NUMERIC(pmodel);   PROTECT(Rse_m);
-     coefficients = REAL(Rcoef_m);  
+     coefficients = REAL(Rcoef_m);
      se_m = REAL(Rse_m);
      for (j=0, l=0; j < pmodel; j++) {
        XtYwork[j] = XtY[model_m[j]];
        for  ( i = 0; i < pmodel; i++) {
 	 XtXwork[j*pmodel + i] = XtX[model_m[j]*p + model_m[i]];
-       }		
-      }	 
+       }
+      }
+
+     mse_m = yty;
+     memcpy(coefficients, XtYwork, sizeof(double)*pmodel);
+     cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);
 
-     mse_m = yty; 
-     memcpy(coefficients, XtYwork, sizeof(double)*pmodel); 
-     cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);  
-     
      R2_m = 1.0 - (mse_m * (double) ( nobs - pmodel))/SSY;
      prior_m = compute_prior_probs(model,pmodel,p, modelprior);
      gexpectations(p, pmodel, nobs, R2_m, alpha, INTEGER(method)[0], RSquareFull, SSY, &logmargy, &shrinkage_m);
      postnew = logmargy + log(prior_m);
-    }	
+    }
    else {
      new_loc = branch->where;
-     postnew =  REAL(logmarg)[new_loc] + log(REAL(priorprobs)[new_loc]);      
-   } 
+     postnew =  REAL(logmarg)[new_loc] + log(REAL(priorprobs)[new_loc]);
+   }
 
    MH = exp(postnew - postold + pigammaold - pigammanew);
    // Rprintf("it %d MH %lf  new %lf old %lf propold %lf propnew %lf \n", m, MH, postnew, postold, pigammanew, pigammaold);
    if (unif_rand() < MH) {
-     
+
      if (newmodel ==1)  {
        new_loc = nUnique;
 
@@ -490,19 +490,19 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 
        INTEGER(modeldim)[nUnique] = pmodel;
        SET_ELEMENT(modelspace, nUnique, Rmodel_m);
-       
+
        SET_ELEMENT(beta, nUnique, Rcoef_m);
        SET_ELEMENT(se, nUnique, Rse_m);
-       
+
        REAL(R2)[nUnique] = R2_m;
        REAL(mse)[nUnique] = mse_m;
-       
+
        REAL(logmarg)[nUnique] = logmargy;
        REAL(shrinkage)[nUnique] = shrinkage_m;
        REAL(priorprobs)[nUnique] = prior_m;
        UNPROTECT(3);
-       ++nUnique; 
-     }	
+       ++nUnique;
+     }
 
      old_loc = new_loc;
      pigammaold = pigammanew;
@@ -513,8 +513,8 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
    }
    else  {
      if (newmodel == 1) UNPROTECT(3);
-   }	
- 
+   }
+
    INTEGER(counts)[old_loc] += 1;
 
    for (i = 0; i < n; i++) {
@@ -524,22 +524,22 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
    F77_NAME(dsyr)("U", &n,  &one, &real_model[0], &inc,  &SSgam[0], &n);
    m++;
 
-   
+
    rem = modf((double) m/(double) update, &mod);
    if (rem  == 0.0) {
      mcurrent = nUnique;
      compute_modelprobs(modelprobs, logmarg, priorprobs,mcurrent);
-     compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);        
+     compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);
 
      for (i = 0; i < n; i++) {
-       marg_probs[i] = wt*(REAL(MCMCprobs)[vars[i].index]/ (double) m) + 
+       marg_probs[i] = wt*(REAL(MCMCprobs)[vars[i].index]/ (double) m) +
 	 (1.0 - wt)*probs[vars[i].index];
      }
      update_Cov(Cov, priorCov, SSgam, marg_probs, n, m, print);
      // Initialize post old proposal
      pigammaold = 0.0;
      for (i = 0; i < n; i++) {
-       if (modelold[vars[i].index] == 1 ){	
+       if (modelold[vars[i].index] == 1 ){
 	 real_model[i] = 1.0;
 	 pigammaold += log(cond_prob(real_model,i, n, marg_probs,Cov, delta));
        }
@@ -552,10 +552,10 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 
  mcurrent = nUnique;
  compute_modelprobs(modelprobs, logmarg, priorprobs,mcurrent);
- compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);        
+ compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);
  wt = 0.1;
  for (i = 0; i < n; i++) {
-   marg_probs[i] = wt* (REAL(MCMCprobs)[vars[i].index]/ (double) m) + 
+   marg_probs[i] = wt* (REAL(MCMCprobs)[vars[i].index]/ (double) m) +
 				    (1.0 - wt)*probs[vars[i].index];
    //  marg_probs[n-1-i] =  REAL(MCMCprobs)[vars[i].index]/ (double) m;
   REAL(MCMCprobs)[vars[i].index] /= (double) m;
@@ -563,28 +563,28 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 
  update_Cov(Cov, priorCov, SSgam, marg_probs, n, m, print);
 
-//  Now sample W/O Replacement 
+//  Now sample W/O Replacement
 // Rprintf("NumUnique Models Accepted %d \n", nUnique);
  INTEGER(NumUnique)[0] = nUnique;
 
  if (nUnique < k) {
 
     //    compute_modelprobs(modelprobs, logmarg, priorprobs,mcurrent);
-    //    compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);        
-    
+    //    compute_margprobs(modelspace, modeldim, modelprobs, probs, mcurrent, p);
+
    //   update_MCMC_probs(MCMC_probs, vars, n, p);
    //   Rprintf("Update Tree\n");
 
-   update_cond_tree(modelspace, tree, modeldim, vars, p, n, nUnique, modelwork, real_model, marg_probs, Cov, eps);      
-  
-         
+   update_cond_tree(modelspace, tree, modeldim, vars, p, n, nUnique, modelwork, real_model, marg_probs, Cov, eps);
+
+
    //   Rprintf("\nNow sample the rest without replacement\n");
-   
+
    for (m = nUnique; m < k; m++) {
      INTEGER(modeldim)[m]  = n_sure;
-     
+
      branch = tree;
-  
+
      for (i = 0; i< n; i++) {
        pigamma[i] = 1.0;
 
@@ -592,13 +592,13 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 	 branch->prob = cond_prob(real_model,i, n, marg_probs,Cov, delta);
 	 branch->update = m+mcurrent;
        }
-       	 
+
        bit =  withprob(branch->prob);
        real_model[n-i-1] = (double) bit;
-     
+
        if (bit == 1) {
 	 for (j=0; j<=i; j++)  pigamma[j] *= branch->prob;
-	 if (i < n-1 && branch->one == NULL) 
+	 if (i < n-1 && branch->one == NULL)
 	 //	    branch->one = make_node(vars[i+1].prob);
 	 branch->one = make_node(cond_prob(real_model,i+1, n, marg_probs,Cov , delta));
        if (i == n-1 && branch->one == NULL)
@@ -614,15 +614,15 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 	 branch->zero = make_node(0.0);
        branch = branch->zero;
      }
-       model[vars[i].index] = bit; 
+       model[vars[i].index] = bit;
        INTEGER(modeldim)[m]  += bit;
      }
 
-     REAL(sampleprobs)[m] = pigamma[0]; 
+     REAL(sampleprobs)[m] = pigamma[0];
 
      pmodel = INTEGER(modeldim)[m];
 
-    // Now subtract off the visited probability mass. 
+    // Now subtract off the visited probability mass.
      branch=tree;
      for (i = 0; i < n; i++) {
        bit = model[vars[i].index];
@@ -644,59 +644,59 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 	 }
 	 else prone = prone/denom;
        }
-       if (prone > 1.0 || prone < 0.0) 
+       if (prone > 1.0 || prone < 0.0)
 	 	 Rprintf("%d %d Probability > 1!!! %le %le  %le %le \n",
 	 	 m, i, prone, branch->prob, denom, pigamma);
       //      if (bit == 1)  pigamma /= (branch->prob);
-      //	      else  pigamma /= (1.0 - branch->prob); 
-      //	      if (pigamma > 1.0) pigamma = 1.0; 
+      //	      else  pigamma /= (1.0 - branch->prob);
+      //	      if (pigamma > 1.0) pigamma = 1.0;
        branch->prob  = prone;
        if (bit == 1) branch = branch->one;
        else  branch = branch->zero;
-      //      Rprintf("%d %d \n",  branch->done, n - i); 
+      //      Rprintf("%d %d \n",  branch->done, n - i);
       //      if (log((double) branch->done) < (n - i)*log(2.0)) {
       //	if (bit == 1) branch = branch->one;
       //	else  branch = branch->zero;
       //}
       //else {
       //	    branch->one = NULL;
-      //	    branch->zero = NULL; 
-      //	    break; } 
+      //	    branch->zero = NULL;
+      //	    break; }
      }
-    /* Now get model specific calculations */ 
+    /* Now get model specific calculations */
 
     PROTECT(Rmodel_m = allocVector(INTSXP, pmodel));
     model_m = INTEGER(Rmodel_m);
 
-    for (j = 0, l=0; j < p; j++) {  
+    for (j = 0, l=0; j < p; j++) {
       if (model[j] == 1) {
 	model_m[l] = j;
 	l +=1;}
-      }	
- 
+      }
+
 
       SET_ELEMENT(modelspace, m, Rmodel_m);
-   
+
       for (j=0, l=0; j < pmodel; j++) {
 	XtYwork[j] = XtY[model_m[j]];
         for  ( i = 0; i < pmodel; i++) {
 	  XtXwork[j*pmodel + i] = XtX[model_m[j]*p + model_m[i]];
-	}	
-      } 
+	}
+      }
+
 
-    
       PROTECT(Rcoef_m = allocVector(REALSXP,pmodel));
       PROTECT(Rse_m = allocVector(REALSXP,pmodel));
-      coefficients = REAL(Rcoef_m);  
+      coefficients = REAL(Rcoef_m);
       se_m = REAL(Rse_m);
-  
-      mse_m = yty; 
-      memcpy(coefficients, XtYwork, sizeof(double)*pmodel); 
-      cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);  
 
-  
-    //    olsreg(Ywork, Xwork, coefficients, se_m, &mse_m, &pmodel, &nobs, pivot,qraux,work,residuals,effects,v,betaols);   
-  
+      mse_m = yty;
+      memcpy(coefficients, XtYwork, sizeof(double)*pmodel);
+      cholreg(XtYwork, XtXwork, coefficients, se_m, &mse_m, pmodel, nobs);
+
+
+    //    olsreg(Ywork, Xwork, coefficients, se_m, &mse_m, &pmodel, &nobs, pivot,qraux,work,residuals,effects,v,betaols);
+
       R2_m = 1.0 - (mse_m * (double) ( nobs - pmodel))/SSY;
 
       SET_ELEMENT(beta, m, Rcoef_m);
@@ -709,17 +709,17 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
    REAL(logmarg)[m] = logmargy;
    REAL(shrinkage)[m] = shrinkage_m;
    REAL(priorprobs)[m] = compute_prior_probs(model,pmodel,p, modelprior);
-       
-   UNPROTECT(3);  
-   }	
+
+   UNPROTECT(3);
+   }
  }
 
 
  // Rprintf("modelprobs\n");
  compute_modelprobs(modelprobs, logmarg, priorprobs,k);
  // Rprintf("marginal probs\n");
- compute_margprobs(modelspace, modeldim, modelprobs, probs, k, p);  
- 
+ compute_margprobs(modelspace, modeldim, modelprobs, probs, k, p);
+
  // Rprintf("saving\n");
   SET_VECTOR_ELT(ANS, 0, Rprobs);
   SET_STRING_ELT(ANS_names, 0, mkChar("probne0"));
@@ -753,7 +753,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
 
   SET_VECTOR_ELT(ANS, 10, modeldim);
   SET_STRING_ELT(ANS_names, 10, mkChar("size"));
- 
+
   SET_VECTOR_ELT(ANS, 11, R2);
   SET_STRING_ELT(ANS_names, 11, mkChar("R2"));
 
@@ -771,7 +771,7 @@ SEXP amcmc(SEXP Y, SEXP X,  SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
   //  Rprintf("Return\n");
   PutRNGstate();
 
-  return(ANS);  
+  return(ANS);
 }
 
 double random_walk(int *model, struct Var *vars, int n) {
@@ -798,15 +798,15 @@ double random_switch(int *model, struct Var *vars, int n, int pmodel, int *varin
         {
 	  if (model[vars[j].index]==0) {varout[k] = vars[j].index; k++;}
 	  j++ ;
-        }	
-      num_to_swap_out = k;	
+        }
+      num_to_swap_out = k;
 
       swapin = ftrunc(unif_rand()*num_to_swap_in);    // swapin :corresponds to position of randomly chosen included variable
       swapout = ftrunc(unif_rand()*num_to_swap_out);  // swapout :corresponds to position of randomly chosen excluded variable
 
       model[varin[swapin]] = 0;
-      model[varout[swapout]] =1; 
-   
+      model[varout[swapout]] =1;
+
 
     return(1.0);
 }
@@ -815,8 +815,8 @@ double random_switch(int *model, struct Var *vars, int n, int pmodel, int *varin
 double cond_prob(double *model, int j, int n, double *mean, double *beta_matrix , double delta) {
   double  prob;
   int i;
- 
-  prob = mean[j]; 
+
+  prob = mean[j];
   //  Rprintf("%f\n", prob);
   for (i = 0; i < j; i++) {
     prob += -beta_matrix[j*n + i]*(model[i] - mean[i])/beta_matrix[j*n+j];
@@ -842,7 +842,7 @@ void update_cond_tree(SEXP modelspace, struct Node *tree, SEXP modeldim, struct
     PROTECT(model_m = VECTOR_ELT(modelspace, m));
 
     for (i = 0; i < p; i++) model[i] = 0;
-    for (i = 0; i < INTEGER(modeldim)[m]; i++) 
+    for (i = 0; i < INTEGER(modeldim)[m]; i++)
        model[INTEGER(model_m)[i]] = 1;
     for (i = 0; i < p; i++) real_model[p-1-i] = (double) model[vars[i].index];
 
@@ -890,7 +890,7 @@ void update_cond_tree(SEXP modelspace, struct Node *tree, SEXP modeldim, struct
 void  update_Cov(double *Cov, double *priorCov, double *SSgam, double *marg_probs, int n, int m, int print) {
   double alpha, one=1.0;
   int matsize=n*n, inc=1, i,j,info=1;
-    
+
   memcpy(Cov, SSgam, sizeof(double)*matsize);
   if (print == 1) {
    Rprintf("SS: %d iterations\n", m);
@@ -903,14 +903,14 @@ void  update_Cov(double *Cov, double *priorCov, double *SSgam, double *marg_prob
     }
   }
   alpha  = -(double) m;
-  // Compute SSgam - m prob prob^T 
+  // Compute SSgam - m prob prob^T
   F77_NAME(dsyr)("U", &n,  &alpha, &marg_probs[0], &inc,  &Cov[0], &n);
   alpha = 1.0/(double) m;
   // divide SSgam - m prob prob^T by m -> Cov
   F77_NAME(dscal)(&matsize,  &alpha,  &Cov[0], &inc);
   // Add priorCov to Cov
   F77_NAME(daxpy)(&matsize, &one, &priorCov[0], &inc, &Cov[0], &inc);
-  
+
   if (print == 1) {
     Rprintf("Cov:\n");
 
@@ -929,6 +929,6 @@ void  update_Cov(double *Cov, double *priorCov, double *SSgam, double *marg_prob
       for(i = 0; i < n; i++){
 	Rprintf("%f ", Cov[i*n + j]);}
       Rprintf("\n");
-    } 
+    }
   }
 }
